@@ -37,6 +37,10 @@
 #endif
 #endif
 
+#ifdef BCT
+#include "bct.h"
+#endif
+
 #include "config.h"
 
 #include <string.h>
@@ -175,27 +179,29 @@ typedef struct {
 
   gboolean cachelist_disable_screensaver;
   gboolean goto_disable_screensaver;
-  gboolean cachelist_update;
 
   HildonProgram *program;
   HildonWindow *window;
   osso_context_t *osso_context;
-  GtkWidget *bct;
-  gpx_t *search_results;
+#else
+  GtkWidget *window;
+#endif
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+  gboolean cachelist_update;
+
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
   /* reference to enable/disable these while walking the crumb trail */
   GtkWidget *menu_import, *menu_export;
   GtkWidget *menu_search;
+
+  GtkWidget *bct;
 #endif
 
   /* keep track of current "path" in the bread crumb trail */
   gpx_t *cur_gpx;
   cache_t *cur_cache;
 
-#else
-  GtkWidget *window;
-#endif
+  gpx_t *search_results;
 
 #ifdef ENABLE_OSM_GPS_MAP
   struct {
