@@ -35,7 +35,7 @@
 
 extern char *strcasestr (__const char *__haystack, __const char *__needle);
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
 static void crumb_add(appdata_t *appdata, char *name, int level, 
 		      gpointer user_data);
 
@@ -95,8 +95,12 @@ void errorf(const char *fmt, ...) {
   GtkWidget *dialog = gtk_message_dialog_new(
 			   GTK_WINDOW(NULL),
 			   GTK_DIALOG_DESTROY_WITH_PARENT,
-			   GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-			   buf);
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+			   GTK_MESSAGE_ERROR, 
+#else
+			   GTK_MESSAGE_OTHER, 			   
+#endif
+			   GTK_BUTTONS_CLOSE, buf);
 
   gtk_window_set_title(GTK_WINDOW(dialog), _("ERROR"));
 
@@ -222,7 +226,7 @@ void cachelist_view_onRowActivated(GtkTreeView        *treeview,
   if(gtk_tree_model_get_iter(model, &iter, path)) {
     cache_t *cache;
     gtk_tree_model_get(model, &iter, CACHELIST_COL_DATA, &cache, -1);
-#ifndef USE_BREAD_CRUMB_TRAIL
+#if !defined(USE_BREAD_CRUMB_TRAIL) && !defined(BCT)
     cache_dialog(appdata, cache);
 #else
     gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
@@ -274,13 +278,6 @@ static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 				   cache_t *sel_cache);
 
 void cachelist_redraw(appdata_t *appdata) {
-#ifndef USE_MAEMO
-  //  gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
-  //  appdata->cur_view = gpxlist_create_view_and_model(appdata, NULL);
-  //  gtk_box_pack_start_defaults(GTK_BOX(appdata->vbox), appdata->cur_view);
-  // gtk_widget_show_all(appdata->vbox);
-#else
-
   if(!appdata->cur_view) {
     printf("cachelist redraw: no active view\n");
     return;
@@ -298,8 +295,6 @@ void cachelist_redraw(appdata_t *appdata) {
   if(redraw) {
     GtkWidget *container = appdata->vbox;
 
-    printf("redraw %d\n", redraw);
-
 #ifdef USE_STACKABLE_WINDOW
     HildonWindowStack *stack = hildon_window_stack_get_default();
     container = hildon_window_stack_peek(stack);
@@ -326,7 +321,6 @@ void cachelist_redraw(appdata_t *appdata) {
     
     gtk_widget_show_all(container);
   }
-#endif
 }
 
 
@@ -334,19 +328,19 @@ static gboolean cachelist_update(gpointer data) {
 
   printf("cachelist timer fired!\n");
 
-#ifdef USE_MAEMO
   appdata_t *appdata = (appdata_t*)data;
 
   if(appdata->cur_cache)
     return TRUE;
 
+#ifdef USE_MAEMO
   if(appdata->cachelist_disable_screensaver)
     if (osso_display_blanking_pause(appdata->osso_context) != OSSO_OK) 
       fprintf(stderr, "error with display blank\n");
+#endif
 
   if(appdata->cachelist_update)
     cachelist_redraw(appdata);
-#endif
 
   return TRUE;
 }
@@ -593,6 +587,10 @@ void on_cachelist_destroy(GtkWidget *widget, appdata_t *appdata) {
   }
   appdata->cur_gpx = NULL;
 
+#ifdef ENABLE_OSM_GPS_MAP
+  map_update(appdata);
+#endif
+
   /* restore cur_view */
   appdata->cur_view = g_object_get_data(G_OBJECT(widget), "cur_view");
 }
@@ -619,6 +617,10 @@ void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
 		   G_CALLBACK(on_cachelist_destroy), appdata);
 
   gtk_widget_show_all(window);
+
+#ifdef ENABLE_OSM_GPS_MAP
+  map_update(appdata);
+#endif
 }
 #endif
 #endif
@@ -833,7 +835,7 @@ static void gpxlist_view_onRowActivated(GtkTreeView *treeview,
       
 	gpx_busy_dialog_destroy(dialog);
       }
-#ifndef USE_BREAD_CRUMB_TRAIL
+#if !defined(USE_BREAD_CRUMB_TRAIL) && !defined(BCT)
 #ifdef USE_STACKABLE_WINDOW
       if(!appdata->cur_gpx)
 #endif
@@ -1456,7 +1458,7 @@ cb_menu_search(GtkWidget *window, gpointer data) {
 
       printf("Search for %s (flags = %x)...\n", p, appdata->search);
 
-#ifndef USE_BREAD_CRUMB_TRAIL
+#if !defined(USE_BREAD_CRUMB_TRAIL) && !defined(BCT)
       gpx_t *found =
 	search_do(appdata, appdata->gpx, p, appdata->search, FALSE);
 
@@ -1552,7 +1554,7 @@ cb_menu_export_log(GtkWidget *widget, gpointer data) {
   notes_log_export(appdata);
 }
 
-#ifdef USE_MAEMO
+#ifdef ENABLE_MAEMO_MAPPER
 static void 
 cb_menu_export_mmpoi(GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -1671,8 +1673,10 @@ static void submenu_cleanup(GtkWidget *menu) {
 }
 
 static const menu_entry_t submenu_export_entries[] = {
+#ifdef ENABLE_MAEMO_MAPPER
   { "Export to Maemo Mapper" , "Save a Maemo Mapper POI file",
     G_CALLBACK(cb_menu_export_mmpoi)  },
+#endif
   { "Export Field Notes",      "Save a Garmin Field Notes file",
     G_CALLBACK(cb_menu_export_log)    },
   { "Export Garmin GPX",       "Save modified waypoints in GPX file",
@@ -1759,12 +1763,10 @@ HildonAppMenu *menu_create(appdata_t *appdata, int mode) {
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
 #ifdef ENABLE_OSM_GPS_MAP
-  if((mode == MENU_GPXLIST) || (mode == MENU_CACHELIST)) {
     button = gtk_button_new_with_label(_("Map"));
     g_signal_connect_after(button, "clicked", 
 			   G_CALLBACK(cb_menu_map), appdata);
     hildon_app_menu_append(menu, GTK_BUTTON(button));
-  }
 #endif
 
 #ifdef HILDON_HELP
@@ -1784,7 +1786,7 @@ void menu_create(appdata_t *appdata) {
   GtkWidget *menu, *item;  
   menu = gtk_menu_new();
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
   appdata->menu_import = 
 #endif
   item = gtk_menu_item_new_with_label(_("Import"));
@@ -1814,7 +1816,7 @@ void menu_create(appdata_t *appdata) {
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_remove), appdata);
 #endif
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
   appdata->menu_export = 
 #endif
     item = gtk_menu_item_new_with_label(_("Export"));
@@ -1822,7 +1824,7 @@ void menu_create(appdata_t *appdata) {
   submenu = gtk_menu_new();
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
 
-#ifdef USE_MAEMO
+#ifdef ENABLE_MAEMO_MAPPER
   item = gtk_menu_item_new_with_label( _("Maemo Mapper POI") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", 
@@ -1839,7 +1841,7 @@ void menu_create(appdata_t *appdata) {
   g_signal_connect(item, "activate", 
 		   GTK_SIGNAL_FUNC(cb_menu_export_garmin), appdata);
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
   appdata->menu_search = 
 #endif
   item = gtk_menu_item_new_with_label( _("Search") );
@@ -2046,7 +2048,7 @@ gboolean on_window_key_press(GtkWidget *widget,
   return handled;
 }
 
-#ifdef USE_BREAD_CRUMB_TRAIL
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
 typedef struct {
   int level;
   appdata_t *appdata;
@@ -2138,6 +2140,10 @@ crumb_back(gpointer data) {
 
   gtk_widget_show_all(crumb->appdata->vbox);    
   g_free(data);
+
+#ifdef ENABLE_OSM_GPS_MAP
+  map_update(crumb->appdata);
+#endif
 }
 
 static void crumb_add(appdata_t *appdata, char *name, int level, 
@@ -2178,8 +2184,16 @@ static void crumb_add(appdata_t *appdata, char *name, int level,
 #endif
   }
 
+#ifdef USE_BREAD_CRUMB_TRAIL
   hildon_bread_crumb_trail_push_text(HILDON_BREAD_CRUMB_TRAIL(appdata->bct),
 				     name, crumb, (GDestroyNotify)crumb_back);
+#else
+  bct_push_text(appdata->bct, name, crumb, (GDestroyNotify)crumb_back);
+#endif
+
+#ifdef ENABLE_OSM_GPS_MAP
+  map_update(appdata);
+#endif
 }
 #endif // USE_BREAD_CRUMB_TRAIL
 
@@ -2191,18 +2205,6 @@ void main_after_settings_redraw(appdata_t *appdata, int flags) {
     return;
   }
 
-#ifndef USE_MAEMO
-  // in non-maemo setup this can only affect the main screen as
-  // the menu is blocked while a dialog is open. also the main
-  // screen is always present
-  if(appdata->gpxlist_items != appdata->cur_items) {
-    /* re-do the main screen */
-    gtk_container_remove(GTK_CONTAINER(appdata->vbox), appdata->cur_view);
-    appdata->cur_view = gpxlist_create_view_and_model(appdata, NULL);
-    gtk_box_pack_start_defaults(GTK_BOX(appdata->vbox), appdata->cur_view);
-    gtk_widget_show_all(appdata->vbox);
-  }
-#else
   /* a cache screen cannot be changed from the settings and thus doesn't */
   /* need to be redrawn */
   if(appdata->cur_cache) {
@@ -2257,7 +2259,6 @@ void main_after_settings_redraw(appdata_t *appdata, int flags) {
     
     gtk_widget_show_all(container);
   }
-#endif // USE_MAEMO
 }
 
 int main(int argc, char *argv[]) {
@@ -2286,7 +2287,9 @@ int main(int argc, char *argv[]) {
     fprintf(stderr, "error initiating osso context\n");
   }
 
+#ifdef ENABLE_MAEMO_MAPPER
   dbus_register(&appdata);
+#endif
 #endif
 
   icons_init();
@@ -2311,7 +2314,7 @@ int main(int argc, char *argv[]) {
   /* Create a Window. */
   appdata.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   /* Set a decent default size for the window. */
-  gtk_window_set_default_size(GTK_WINDOW(appdata.window), 500, 300);
+  gtk_window_set_default_size(GTK_WINDOW(appdata.window), 640, 480);
 #endif
 
 #if MAEMO_VERSION_MAJOR == 5
@@ -2339,6 +2342,16 @@ int main(int argc, char *argv[]) {
   gtk_box_pack_start(GTK_BOX(appdata.vbox), appdata.bct, FALSE,FALSE,0);
 
   hildon_bread_crumb_trail_clear(HILDON_BREAD_CRUMB_TRAIL(appdata.bct));
+#else 
+#ifdef BCT
+  /* on non-hildon machines we use some custom made breadcrumbtrail */
+  /* replacement */
+  appdata.bct = bct_new();
+  gtk_box_pack_start(GTK_BOX(appdata.vbox), appdata.bct, FALSE,FALSE,0);
+#endif
+#endif
+
+#if defined(USE_BREAD_CRUMB_TRAIL) || defined(BCT)
   crumb_add(&appdata, "GPX", CRUMB_GPXLIST, NULL);
 #endif
 
