@@ -175,13 +175,33 @@ static gboolean on_map_configure(GtkWidget *widget,
   return FALSE;
 }
 
-static void map_draw_cachelist(GtkWidget *map, cache_t *cache) {
-  while(cache) {
-    GdkPixbuf *icon = icon_get(ICON_CACHE_TYPE, cache->type);
+static void map_draw_cache(GtkWidget *map, cache_t *cache) {
+  GdkPixbuf *icon = icon_get(ICON_CACHE_TYPE, cache->type);
     
+  /* check if there's also an overwritten coordinate */
+  if(cache->notes && cache->notes->override) {
+    GdkPixbuf *over = icon_get(ICON_MISC, 1);
+
+    osm_gps_map_add_image(OSM_GPS_MAP(map), 
+	  cache->notes->pos.lat, cache->notes->pos.lon, icon);
+
+    osm_gps_map_add_image(OSM_GPS_MAP(map),
+	  cache->notes->pos.lat, cache->notes->pos.lon, over);
+  } else
     osm_gps_map_add_image(OSM_GPS_MAP(map), 
 			  cache->pos.lat, cache->pos.lon, icon);
 
+}
+
+static void map_draw_gpx(appdata_t *appdata, GtkWidget *map, gpx_t *gpx) {
+  if(!gpx->notes_loaded) {
+    notes_load_all(appdata, gpx);
+    gpx->notes_loaded = TRUE;
+  }
+
+  cache_t *cache = gpx->cache;
+  while(cache) {
+    map_draw_cache(map, cache);
     cache = cache->next;
   }
 }
@@ -190,9 +210,11 @@ static void
 map_cachelist_nearest(cache_t *cache, pos_t *pos, 
 		      cache_t **result, float *distance) {
   while(cache) {
+    pos_t cpos = gpx_cache_pos(cache);
+
     float dist = 
-      pow(cache->pos.lat - pos->lat, 2) + 
-      pow(cache->pos.lon - pos->lon, 2);
+      pow(cpos.lat - pos->lat, 2) + 
+      pow(cpos.lon - pos->lon, 2);
 
     if(!(dist > *distance)) {
       *result = cache;
@@ -207,21 +229,18 @@ static cache_t *map_closest(map_context_t *context, pos_t *pos) {
   cache_t *result = NULL;
   float distance = NAN;
   
-#ifdef USE_MAEMO
-  if(!context->appdata->cur_gpx) {
-#endif
+  if(!context->appdata->cur_gpx && !context->appdata->cur_cache) {
     /* search all geocaches */
     gpx_t *gpx = context->appdata->gpx;
     while(gpx) {
       map_cachelist_nearest(gpx->cache, pos, &result, &distance);
       gpx = gpx->next;
     }
-#ifdef USE_MAEMO
-  } else {
+  } else if(context->appdata->cur_gpx) {
     map_cachelist_nearest(context->appdata->cur_gpx->cache, 
 			  pos, &result, &distance);
-  }
-#endif
+  } else
+    result = context->appdata->cur_gpx->cache;
 
   return result;
 }
@@ -256,8 +275,10 @@ on_map_button_press_event(GtkWidget *widget,
 
   cache_t *nearest = map_closest(context, &pos);  
   if(nearest) {
-    float dist = gpx_pos_get_distance(pos, nearest->pos, FALSE);
-    if(dist2pixel(context, dist, nearest->pos.lat) < CLICK_FUZZ) 
+    pos_t cpos = gpx_cache_pos(nearest);
+
+    float dist = gpx_pos_get_distance(pos, cpos, FALSE);
+    if(dist2pixel(context, dist, cpos.lat) < CLICK_FUZZ) 
       context->press_on = nearest;
   }
   
@@ -313,6 +334,11 @@ balloon_draw_cb(cairo_t *cr, OsmGpsMapRect_t *rect, gpointer data) {
   GdkPixbuf *icon = icon_get(ICON_CACHE_TYPE, cache->type);
   cairo_draw_pixbuf(cr, icon, x, y);
 
+  if(cache->notes && cache->notes->override) {
+    GdkPixbuf *over = icon_get(ICON_MISC, 1);
+    cairo_draw_pixbuf(cr, over, x, y);
+  }
+
   /* ... and right of it the waypoint id */
   cairo_text_extents_t extents;
 
@@ -412,7 +438,11 @@ on_map_button_release_event(GtkWidget *widget,
 			    GdkEventButton *event, map_context_t *context) {
   OsmGpsMap *map = OSM_GPS_MAP(context->widget);
 
-  if(context->press_on) {
+  /* in "MAP_CACHE" state only one cache is visible */
+  /* and the map is in navigation mode. the balloon is */
+  /* pretty useless there */
+  if(context->press_on && (context->state != MAP_CACHE)) {
+
     coord_t coo;
     coo = osm_gps_map_get_co_ordinates(map, event->x, event->y);
 
@@ -421,10 +451,12 @@ on_map_button_release_event(GtkWidget *widget,
 
     cache_t *nearest = map_closest(context, &pos);  
     if(nearest && nearest == context->press_on) {
-      float dist = gpx_pos_get_distance(pos, nearest->pos, FALSE);
-      if(dist2pixel(context, dist, nearest->pos.lat) < CLICK_FUZZ) {
+      pos_t cpos = gpx_cache_pos(nearest);
+
+      float dist = gpx_pos_get_distance(pos, cpos, FALSE);
+      if(dist2pixel(context, dist, cpos.lat) < CLICK_FUZZ) {
 	
-	osm_gps_map_osd_draw_balloon(map, nearest->pos.lat, nearest->pos.lon,
+	osm_gps_map_osd_draw_balloon(map, cpos.lat, cpos.lon,
 				     balloon_draw_cb, nearest);
       }
     }
@@ -490,18 +522,111 @@ on_window_realize(GtkWidget *widget, gpointer data) {
 }
 #endif
 
+/* draw geocaches and set window title */
+static void map_setup(map_context_t *context) {
+  char *name = NULL;
+
+  if(!context->appdata->cur_gpx && !context->appdata->cur_cache) {
+    if(context->state != MAP_ALL) {
+      printf("map_setp(ALL)\n");
+
+      /* no navigation in this mode */
+      osm_gps_map_osd_clear_nav (OSM_GPS_MAP(context->widget));
+
+      /* clear all existing ccahe images */
+      osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
+
+      /* draw all geocaches */
+      gpx_t *gpx = context->appdata->gpx;
+      while(gpx) {
+	map_draw_gpx(context->appdata, context->widget, gpx);
+	gpx = gpx->next;
+      }
+      name = g_strdup(_("all"));
+      context->state = MAP_ALL;
+    }
+  } else if(!context->appdata->cur_cache) {
+    if(context->state != MAP_GPX) {
+      printf("map_setp(GPX)\n");
+
+      /* no navigation in this mode */
+      osm_gps_map_osd_clear_nav (OSM_GPS_MAP(context->widget));
+
+      /* clear all existing ccahe images */
+      osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
+
+      map_draw_gpx(context->appdata, context->widget, 
+		   context->appdata->cur_gpx);
+      name = g_strdup(context->appdata->cur_gpx->name);
+      context->state = MAP_GPX;
+    }
+  } else {
+    cache_t *cache = context->appdata->cur_cache;
+    
+    printf("map_setp(CACHE)\n");
+    
+    /* no balloons in this mode */
+    osm_gps_map_osd_clear_balloon (OSM_GPS_MAP(context->widget));
+    
+    /* clear all existing ccahe images */
+    osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
+    
+    map_draw_cache(context->widget, cache);
+    name = g_strdup(cache->name);
+    context->state = MAP_CACHE;
+    
+    /* navigation in this mode! */
+    pos_t cpos = gpx_cache_pos(cache);
+    osm_gps_map_osd_draw_nav (OSM_GPS_MAP(context->widget), 
+			      context->appdata->imperial,
+			      cpos.lat, cpos.lon, cache->name);
+  }
+
+  if(name) {
+    char *title = g_strdup_printf(_("Map - %s"), name);
+    g_free(name);
+
+    gtk_window_set_title(GTK_WINDOW(context->window), title);
+    
+    g_free(title);
+  } else
+    printf("map_setup(keep)\n");
+}
+
+#ifdef USE_MAEMO
+/* on maemo a window is either on top or completely invisible. this means that */
+/* we only need to update the map window if its raised. on ordinary desktops this */
+/* is different and we always update */
+static gboolean on_focus_in(GtkWidget *widget, GdkEventFocus *event,
+			 gpointer data) {
+
+  map_setup((map_context_t*)data);
+  return FALSE;
+}  
+#endif
+
+void map_update(appdata_t *appdata) {
+#ifndef USE_MAEMO
+  if(appdata->map.context) 
+    map_setup(appdata->map.context);
+#endif
+}
+
 void map(appdata_t *appdata) {
   map_context_t *context = NULL; 
 
   /* if the map window already exists, just raise it */
   if(appdata->map.context) {
+    printf("using existing map!\n");
     gtk_window_present(GTK_WINDOW(appdata->map.context->window));
+    map_setup(appdata->map.context);
     return;
   }
 
   context = appdata->map.context = g_new0(map_context_t, 1);
   context->appdata = appdata;
   context->map_complete = FALSE;
+  context->state = MAP_NONE;
 
   /* cleanup old (pre 0.8.7) path if it exists */
   char *old_path = g_strdup_printf("%s/map/", appdata->image_path);
@@ -544,51 +669,32 @@ void map(appdata_t *appdata) {
   g_free(path);
 
   osm_gps_map_osd_classic_init(OSM_GPS_MAP(context->widget));
-  
-  char *name = NULL;
-#ifdef USE_MAEMO
-  if(!appdata->cur_gpx) {
-#endif
-    /* draw all geocaches */
-    gpx_t *gpx = appdata->gpx;
-    while(gpx) {
-      map_draw_cachelist(context->widget, gpx->cache);
-      gpx = gpx->next;
-    }
-    name = g_strdup(_("all geocaches"));
-#ifdef USE_MAEMO
-  } else {
-    map_draw_cachelist(context->widget, appdata->cur_gpx->cache);
-    name = g_strdup(appdata->cur_gpx->name);
-  }
-#endif
-
-  char *title = g_strdup_printf(_("Map - %s"), name);
-  g_free(name);
 
 #ifdef USE_MAEMO
-#ifdef USE_STACKABLE_WINDOW
-  context->window = hildon_stackable_window_new();
-  /* try to enable the zoom buttons. don't do this on x86 as it breaks */
-  /* at runtime with cygwin x */
-#ifndef __i386__
+  /* we don't use a stackable window here on fremantle, since */
+  /* this leaves the main window independent from the map and */
+  /* the user can e.g. still navigate the main menu */
+  context->window = hildon_window_new();
+
+#if (MAEMO_VERSION_MAJOR == 5) && !defined(__i386__)
   g_signal_connect(G_OBJECT(context->window), "realize", 
 		   G_CALLBACK(on_window_realize), NULL);
 #endif // MAEMO_VERSION
-#else
-  context->window = hildon_window_new();
-#endif
 #else
   context->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 #endif
 
-  gtk_window_set_title(GTK_WINDOW(context->window), title);
+  /* setup cache state */
+  map_setup(context);
 
 #ifndef USE_MAEMO
   gtk_window_set_default_size(GTK_WINDOW(context->window), 640, 480);
 #endif
 
-  g_free(title);
+#ifdef USE_MAEMO
+  g_signal_connect(G_OBJECT(context->widget), "focus-in-event", 
+		   G_CALLBACK(on_focus_in), context);
+#endif
 
   g_signal_connect(G_OBJECT(context->widget), "configure-event",
 		   G_CALLBACK(on_map_configure), context);
