@@ -319,7 +319,7 @@ static gboolean update(gpointer data) {
   return TRUE;   // fire again
 }
 
-#ifdef USE_MAEMO
+#ifdef ENABLE_MAEMO_MAPPER
 static void on_mm_export_clicked(GtkButton *button, gpointer data) {
   pp_context_t *context = (pp_context_t*)data;
 
@@ -414,7 +414,7 @@ void precise_position(appdata_t *appdata) {
 
   context->handler_id = gtk_timeout_add(1000, update, context);
 
-#ifdef USE_MAEMO
+#ifdef ENABLE_MAEMO_MAPPER
   /* ------------- maemo mapper button ---------------- */  
   GtkWidget *button = gtk_button_new();
   gtk_button_set_image(GTK_BUTTON(button), icon_get_widget(ICON_MISC, 0));
